@@ -27,7 +27,14 @@ sub dump_c
 
     my $type = $self->{type}->dump_c;
 
-    return "alignof($type)";
+    return "__alignof__($type)";
+  }
+
+sub type
+  {
+    my $self = shift;
+
+    return $self->{type};
   }
 
 sub compute
