@@ -7,6 +7,7 @@ use warnings;
 use Exporter;
 
 use CParse::Parser::Perl;
+use CParse::Parser::PerlXS;
 
 our @ISA = qw/Exporter/;
 our @EXPORT = qw/parse_file/;
@@ -16,7 +17,8 @@ our $current_location = undef;
 $::RD_HINT = 1 if $ENV{RD_HINT};
 $::RD_TRACE = 1 if $ENV{RD_TRACE};
 
-my $parser = new CParse::Parser::Perl or die "Couldn't create parser";
+my $parser = $ENV{ICHECK_PARSER_XSUB} ? new CParse::Parser::PerlXS : new CParse::Parser::Perl;
+die "Couldn't create parser" unless $parser;
 
 sub parse_file
   {
