@@ -331,6 +331,8 @@ sub try_token
     return $token;
   }
 
+my %parse_funcs;
+
 sub try_parse
   {
     my $self = shift;
@@ -354,7 +356,9 @@ sub try_parse
       }
 
     print STDERR "CParse::Parser::Perl::try_parse: trying $description\n" if $ENV{ICHECK_DEBUG} > 0;
-    my $parsed = eval "\$self->try_${thing}(\@_)";
+    $parse_funcs{$thing} = eval "\\\&try_${thing}" unless defined $parse_funcs{$thing};
+    die "No function for $thing found" unless $parse_funcs{$thing};
+    my $parsed = $parse_funcs{$thing}->($self, @_);
     die if $@;
 
     print STDERR "CParse::Parser::Perl::try_parse: " . ($parsed ? "found" : "failed") . " $description\n" if $ENV{ICHECK_DEBUG} > 0;
